@@ -77,19 +77,8 @@ class BlueprintsManager(ResourceManager):
         result_json = self._list(path=url)
         return result_json
 
-    def validate(self, blueprint: str, env_type: str = "sandbox", branch: str = None, commit: str = None) -> Blueprint:
+    def validate(self, b64_blueprint_content: str, blueprint: str = "") -> dict:
         url = "validations/blueprints"
-        params = {"blueprint_name": blueprint, "type": env_type}
-
-        if commit and branch in (None, ""):
-            raise ValueError("Since commit is specified, branch is required")
-
-        if branch:
-            params["source"] = {
-                "branch": branch,
-            }
-            params["source"]["commit"] = commit or ""
-
+        params = {"blueprint_name": blueprint, "blueprint_raw_64": b64_blueprint_content}
         result_json = self._post(url, params)
-        result_bp = Blueprint.json_deserialize(self, result_json)
-        return result_bp
+        return result_json
